@@ -27,7 +27,7 @@
 
 #define ARROW_CXX_COMPILER_ID "GNU"
 #define ARROW_CXX_COMPILER_VERSION "10.2.0"
-#define ARROW_CXX_COMPILER_FLAGS "-D_FORTIFY_SOURCE=2 -march=armv8-a -O2 -pipe -fno-plt -fdiagnostics-color=always -O3 -DNDEBUG"
+#define ARROW_CXX_COMPILER_FLAGS "-D_FORTIFY_SOURCE=2 -march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fdiagnostics-color=always -O3 -DNDEBUG"
 
 #define ARROW_GIT_ID ""
 #define ARROW_GIT_DESCRIPTION ""
